@@ -12,6 +12,7 @@ from mercury_engine_data_structures.formats.bres import Bres
 from mercury_engine_data_structures.formats.brev import Brev
 from mercury_engine_data_structures.formats.brfld import Brfld
 from mercury_engine_data_structures.formats.brsa import Brsa
+from mercury_engine_data_structures.formats.ini import Ini
 from mercury_engine_data_structures.formats.pkg import Pkg
 from mercury_engine_data_structures.formats.toc import Toc
 from mercury_engine_data_structures.formats.txt import Txt
@@ -31,6 +32,7 @@ ALL_FORMATS = {
     "BREV": Brev,
     "TOC": Toc,
     "TXT": Txt,
+    "INI": Ini,
 }
 
 
